/*
 * *********************************************************************************************************************
 *
 *          !!
 *        .F88X
 *        X8888Y
 *      .}888888N;
 *        i888888N;        .:!              .I$WI:
 *          R888888I      .'N88~            i8}+8Y&8"l8i$8>8W~'>W8}8]KW+8IIN"8&
 *          .R888888I    .;N8888~          .X8'  "8I.!,/8"  !%NY8`"8I8~~8>,88I
 *            +888888N;  .8888888Y                                  "&&8Y.}8,
 *            ./888888N;  .R888888Y        .'}~    .>}'.`+>  i}!    "i'  +/'  .'i~  !11,.:">,  .~]!  .i}i
 *              ~888888%:  .I888888l      .]88~`1/iY88Ii+1'.R$8$8]"888888888>  Y8$  W8E  X8E  W8888'188Il}Y88$*
 *              18888888    E8888881    .]W%8$`R8X'&8%++N8i,8N%N8+l8%`  .}8N:.R$RE%N88N%N$K$R  188,FE$8%~Y88I
 *            .E888888I  .i8888888'      .:$8I;88+`E8R:/8N,.>881.`$8E/1/]N8X.Y8N`"KF&&FK!'88*."88K./$88%RN888+~
 *            8888888I  .,N888888~        ~88i"8W,!N8*.I88.}888%F,i$88"F88"  888:E8X.>88!i88>`888*.}Fl1]*}1YKi'
 *          i888888N'      I888Y          ]88;/EX*IFKFK88X  K8R  .l8W  88Y  ~88}'88E&%8W.X8N``]88!.$8K  .:W8I
 *        .i888888N;        I8Y          .&8$  .X88!  i881.:%888>I88  ;88]  +88+.';;;;:.Y88X  18N.,88l  .+88/
 *      .:R888888I
 *      .&888888I                                          Copyright (c) 2016-2020.  博锐尚格科技股份有限公司
 *        ~8888'
 *        .!88~                                                                     All rights reserved.
 *
 * *********************************************************************************************************************
 */
import { SColor, SFont,SPoint } from "@persagy-web/draw/";
import { SPolygonEdit } from './../../edit';
import { SGraphItem } from "@persagy-web/graph";
import { Marker } from "./../types/Marker";
import { SMouseEvent } from "@persagy-web/base/lib";
import { ItemOrder } from '@persagy-web/big/lib';
import { uuid } from "./../../big-edit/until";
/**
 * 编辑基础多边形类
 *
 * * @author  韩耀龙(han_yao_long#163.com)
 */
export class SBasePolygonEdit extends SPolygonEdit {
    ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    //属性
    /**编辑相关操作的数据 */
    data: Marker
    /** 起始锚点  */
    startItem: SGraphItem | null = null;
    /** 结束锚点  */
    endItem: SGraphItem | null = null;

    constructor(parent: SGraphItem | null, data: Marker) {
        super(parent);
        // this.textItem.originPosition = STextOrigin.Centrum;
        // this.textItem.isTransform = false;
        this.zOrder = ItemOrder.polygonOrder;
        this.data = data;
        if (!data.ID) {
            data.ID = uuid()
        }
        this.id = data.ID;
        this.name = data.Name;
        // this.text = data.Name;
        if (data) {
            this.setPointList = [];
            let setPointList: SPoint[];
            if (data.OutLine) {
                if (data.OutLine[0] instanceof SPoint) {
                    // @ts-ignore
                    this.setPointList = data.OutLine;
                } else {
                    setPointList = data.OutLine.map(i => {
                        return (new SPoint(i.X, i.Y))
                    })
                    this.setPointList = setPointList;
                }
            }
            if (data.Properties.Zorder) {
                this.zOrder = data.Properties.Zorder;
            }
            // 设置线宽
            if (data.Properties.LineWidth) {
                this.lineWidth = data.Properties.LineWidth;
            }
            if (data.Properties.StrokeColor) {
                this.strokeColor = data.Properties.StrokeColor.includes('#') ? new SColor(data.Properties.StrokeColor) : new SColor(hexify(data.Properties.StrokeColor));
            }
            if (data.Properties.FillColor) {
                this.fillColor = data.Properties.FillColor.includes('#') ? new SColor(data.Properties.FillColor) : new SColor(hexify(data.Properties.FillColor))
            }
            if (data.Properties.TextPos) {
                this.textItem.moveTo(data.Properties.TextPos.X, data.Properties.TextPos.Y);
            }
            if (data.Properties.color) {
                this.color = new SColor(data.Properties.color);
            }
            if (data.Properties.font) {
                this.font = new SFont("sans-serif", data.Properties.font);
            }
            if (data.Properties && data.Properties.IsActive) {
                this.isActive = data.Properties.IsActive;
            }
            if (data.AttachObjectIds && data.AttachObjectIds.length) {
                this.isActive = true;
            }
            switch (data.Properties.LineDash) {
                case "solid":
                    this.lineStyle = SLineStyle.Solid;
                    break;
                case "dotted":
                    this.lineStyle = SLineStyle.Dotted;
                    break;
                case "dashed":
                    this.lineStyle = SLineStyle.Dashed;
                    break;
                default:
                    this.lineStyle = SLineStyle.Solid;
            }
        }
        /**
         * 鼠标按下事件
         *
         * @param   event   保存事件参数
         * @return  boolean
         */
        onMouseDown(event: SMouseEvent): boolean {
            super.onMouseDown(event)
            return true;
        } // Function onMouseDown()

        toData() {
            console.log(1230)
        }
    }